==> iaxmodem_1.1.1~dfsg.orig.tar.gz: iaxmodem-1.1.1/lib/spandsp/src/v27ter_tx_2400_floating_rrc.h <==
#define PULSESHAPER_2400_GAIN        1.000000f
#define PULSESHAPER_2400_COEFF_SETS  20
static const float pulseshaper_2400[PULSESHAPER_2400_COEFF_SETS][9] =
{
    {
           0.0050261981f,     /* Filter 0 */
           0.0107704081f,
          -0.0150784949f,
          -0.0753922201f,
           0.5814534590f,
           0.5814534590f,
          -0.0753922201f,
          -0.0150784949f,
           0.0107704081f
    },
    {
           0.0036769624f,     /* Filter 1 */
           0.0132151788f,
          -0.0108416500f,
          -0.0962477460f,
           0.6703977011f,
           0.4915574836f,
          -0.0543875542f,
          -0.0179957571f,
           0.0079493167f
    },
    {
           0.0020271568f,     /* Filter 2 */
           0.0151310537f,
          -0.0054150755f,
          -0.1159725328f,
           0.7564987705f,
           0.4025542918f,
          -0.0341116983f,
          -0.0195425394f,
           0.0049156957f
    },
    {
           0.0001575806f,     /* Filter 3 */
           0.0163856870f,
           0.0009922293f,
          -0.1335090587f,
           0.8378712700f,
           0.3161905873f,
          -0.0153166425f,
          -0.0197430380f,
           0.0018355795f
    },
    {
          -0.0018345641f,     /* Filter 4 */
           0.0168753681f,
           0.0080958424f,
          -0.1477565732f,
           0.9126905398f,
           0.2340689659f,
           0.0013877622f,
          -0.0186894796f,
          -0.0011314557f
    },
    {
          -0.0038402662f,     /* Filter 5 */
           0.0165323372f,
           0.0155436576f,
          -0.1576073891f,
           0.9792460964f,
           0.1576073967f,
           0.0155436170f,
          -0.0165323542f,
          -0.0038401947f
    },
    {
          -0.0057441235f,     /* Filter 6 */
           0.0153307042f,
           0.0229275652f,
          -0.1619859120f,
           1.0359920618f,
           0.0880058079f,
           0.0268485017f,
          -0.0134685582f,
          -0.0061665117f
    },
    {
          -0.0074304083f,     /* Filter 7 */
           0.0132904385f,
           0.0297988389f,
          -0.1598887936f,
           1.0815943275f,
           0.0262205388f,
           0.0351527365f,
          -0.0097281399f,
          -0.0080126751f
    },
    {
          -0.0087894091f,     /* Filter 8 */
           0.0104791756f,
           0.0356867178f,
          -0.1504249523f,
           1.1149702451f,
          -0.0270525892f,
           0.0404511689f,
          -0.0055604029f,
          -0.0093110519f
    },
    {
          -0.0097237699f,     /* Filter 9 */
           0.0070115978f,
           0.0401196528f,
          -0.1328538516f,
           1.1353219580f,
          -0.0713862169f,
           0.0428697868f,
          -0.0012200200f,
          -0.0100260759f
    },
    {
          -0.0101544656f,     /* Filter 10 */
           0.0030462720f,
           0.0426483505f,
          -0.1066205506f,
           1.1421607874f,
          -0.1066205506f,
           0.0426483505f,
           0.0030462720f,
          -0.0101544656f
    },
    {
          -0.0100260759f,     /* Filter 11 */
          -0.0012200200f,
           0.0428697868f,
          -0.0713862169f,
           1.1353219580f,
          -0.1328538517f,
           0.0401196528f,
           0.0070115978f,
          -0.0097237699f
    },
    {
          -0.0093110519f,     /* Filter 12 */
          -0.0055604029f,
           0.0404511689f,
          -0.0270525892f,
           1.1149702451f,
          -0.1504249524f,
           0.0356867178f,
           0.0104791756f,
          -0.0087894091f
    },
    {
          -0.0080126751f,     /* Filter 13 */
          -0.0097281399f,
           0.0351527365f,
           0.0262205388f,
           1.0815943275f,
          -0.1598887936f,
           0.0297988389f,
           0.0132904385f,
          -0.0074304083f
    },
    {
          -0.0061665117f,     /* Filter 14 */
          -0.0134685582f,
           0.0268485017f,
           0.0880058079f,
           1.0359920618f,
          -0.1619859120f,
           0.0229275652f,
           0.0153307042f,
          -0.0057441235f
    },
    {
          -0.0038401947f,     /* Filter 15 */
          -0.0165323542f,
           0.0155436170f,
           0.1576073967f,
           0.9792460963f,
          -0.1576073891f,
           0.0155436576f,
           0.0165323372f,
          -0.0038402662f
    },
    {
          -0.0011314557f,     /* Filter 16 */
          -0.0186894796f,
           0.0013877622f,
           0.2340689660f,
           0.9126905398f,
          -0.1477565732f,
           0.0080958424f,
           0.0168753681f,
          -0.0018345641f
    },
    {
           0.0018355795f,     /* Filter 17 */
          -0.0197430380f,
          -0.0153166425f,
           0.3161905873f,
           0.8378712699f,
          -0.1335090587f,
           0.0009922293f,
           0.0163856870f,
           0.0001575806f
    },
    {
           0.0049156957f,     /* Filter 18 */
          -0.0195425394f,
          -0.0341116983f,
           0.4025542919f,
           0.7564987705f,
          -0.1159725328f,
          -0.0054150755f,
           0.0151310537f,
           0.0020271568f
    },
    {
           0.0079493167f,     /* Filter 19 */
          -0.0179957571f,
          -0.0543875542f,
           0.4915574837f,
           0.6703977010f,
          -0.0962477460f,
          -0.0108416500f,
           0.0132151788f,
           0.0036769624f
    }
};

==> iaxmodem_1.2.0~dfsg.orig.tar.gz: iaxmodem-1.2.0/lib/spandsp/src/v27ter_tx_2400_floating_rrc.h <==
#define TX_PULSESHAPER_2400_GAIN        1.000000f
#define TX_PULSESHAPER_2400_COEFF_SETS  20
static const float tx_pulseshaper_2400[TX_PULSESHAPER_2400_COEFF_SETS][9] =
{
    {
           0.0050261981f,     /* Filter 0 */
           0.0107704081f,
          -0.0150784949f,
          -0.0753922201f,
           0.5814534590f,
           0.5814534590f,
          -0.0753922201f,
          -0.0150784949f,
           0.0107704081f
    },
    {
           0.0036769624f,     /* Filter 1 */
           0.0132151788f,
          -0.0108416500f,
          -0.0962477460f,
           0.6703977011f,
           0.4915574836f,
          -0.0543875542f,
          -0.0179957571f,
           0.0079493167f
    },
    {
           0.0020271568f,     /* Filter 2 */
           0.0151310537f,
          -0.0054150755f,
          -0.1159725328f,
           0.7564987705f,
           0.4025542918f,
          -0.0341116983f,
          -0.0195425394f,
           0.0049156957f
    },
    {
           0.0001575806f,     /* Filter 3 */
           0.0163856870f,
           0.0009922293f,
          -0.1335090587f,
           0.8378712700f,
           0.3161905873f,
          -0.0153166425f,
          -0.0197430380f,
           0.0018355795f
    },
    {
          -0.0018345641f,     /* Filter 4 */
           0.0168753681f,
           0.0080958424f,
          -0.1477565732f,
           0.9126905398f,
           0.2340689659f,
           0.0013877622f,
          -0.0186894796f,
          -0.0011314557f
    },
    {
          -0.0038402662f,     /* Filter 5 */
           0.0165323372f,
           0.0155436576f,
          -0.1576073891f,
           0.9792460964f,
           0.1576073967f,
           0.0155436170f,
          -0.0165323542f,
          -0.0038401947f
    },
    {
          -0.0057441235f,     /* Filter 6 */
           0.0153307042f,
           0.0229275652f,
          -0.1619859120f,
           1.0359920618f,
           0.0880058079f,
           0.0268485017f,
          -0.0134685582f,
          -0.0061665117f
    },
    {
          -0.0074304083f,     /* Filter 7 */
           0.0132904385f,
           0.0297988389f,
          -0.1598887936f,
           1.0815943275f,
           0.0262205388f,
           0.0351527365f,
          -0.0097281399f,
          -0.0080126751f
    },
    {
          -0.0087894091f,     /* Filter 8 */
           0.0104791756f,
           0.0356867178f,
          -0.1504249523f,
           1.1149702451f,
          -0.0270525892f,
           0.0404511689f,
          -0.0055604029f,
          -0.0093110519f
    },
    {
          -0.0097237699f,     /* Filter 9 */
           0.0070115978f,
           0.0401196528f,
          -0.1328538516f,
           1.1353219580f,
          -0.0713862169f,
           0.0428697868f,
          -0.0012200200f,
          -0.0100260759f
    },
    {
          -0.0101544656f,     /* Filter 10 */
           0.0030462720f,
           0.0426483505f,
          -0.1066205506f,
           1.1421607874f,
          -0.1066205506f,
           0.0426483505f,
           0.0030462720f,
          -0.0101544656f
    },
    {
          -0.0100260759f,     /* Filter 11 */
          -0.0012200200f,
           0.0428697868f,
          -0.0713862169f,
           1.1353219580f,
          -0.1328538517f,
           0.0401196528f,
           0.0070115978f,
          -0.0097237699f
    },
    {
          -0.0093110519f,     /* Filter 12 */
          -0.0055604029f,
           0.0404511689f,
          -0.0270525892f,
           1.1149702451f,
          -0.1504249524f,
           0.0356867178f,
           0.0104791756f,
          -0.0087894091f
    },
    {
          -0.0080126751f,     /* Filter 13 */
          -0.0097281399f,
           0.0351527365f,
           0.0262205388f,
           1.0815943275f,
          -0.1598887936f,
           0.0297988389f,
           0.0132904385f,
          -0.0074304083f
    },
    {
          -0.0061665117f,     /* Filter 14 */
          -0.0134685582f,
           0.0268485017f,
           0.0880058079f,
           1.0359920618f,
          -0.1619859120f,
           0.0229275652f,
           0.0153307042f,
          -0.0057441235f
    },
    {
          -0.0038401947f,     /* Filter 15 */
          -0.0165323542f,
           0.0155436170f,
           0.1576073967f,
           0.9792460963f,
          -0.1576073891f,
           0.0155436576f,
           0.0165323372f,
          -0.0038402662f
    },
    {
          -0.0011314557f,     /* Filter 16 */
          -0.0186894796f,
           0.0013877622f,
           0.2340689660f,
           0.9126905398f,
          -0.1477565732f,
           0.0080958424f,
           0.0168753681f,
          -0.0018345641f
    },
    {
           0.0018355795f,     /* Filter 17 */
          -0.0197430380f,
          -0.0153166425f,
           0.3161905873f,
           0.8378712699f,
          -0.1335090587f,
           0.0009922293f,
           0.0163856870f,
           0.0001575806f
    },
    {
           0.0049156957f,     /* Filter 18 */
          -0.0195425394f,
          -0.0341116983f,
           0.4025542919f,
           0.7564987705f,
          -0.1159725328f,
          -0.0054150755f,
           0.0151310537f,
           0.0020271568f
    },
    {
           0.0079493167f,     /* Filter 19 */
          -0.0179957571f,
          -0.0543875542f,
           0.4915574837f,
           0.6703977010f,
          -0.0962477460f,
          -0.0108416500f,
           0.0132151788f,
           0.0036769624f
    }
};
